%define major     8
%define libname   %mklibname ffi %{major}
%define develname %mklibname ffi -d

Name:		libffi
Version:	3.4.8
Release:	%mkrel 1
Summary:	A portable foreign function interface library
Group:		System/Libraries
License:	BSD
URL:		https://sourceware.org/libffi
Source0:	https://github.com/libffi/libffi/releases/download/v%{version}/libffi-%{version}.tar.gz
Patch0:		libffi-3.1-fix-include-path.patch

%description
The 'libffi' library provides a portable, high level programming interface to
various calling conventions. This allows a programmer to call any function
specified by a call interface description at run time.

FFI stands for Foreign Function Interface. A foreign function interface is the
popular name for the interface that allows code written in one language to call
code written in another language. The 'libffi' library really only provides the
lowest, machine dependent layer of a fully featured foreign function interface.
A layer must exist above 'libffi' that handles type conversions for values
passed between the two languages.

%package -n	%{libname}
Summary:	A portable foreign function interface library
Group:		System/Libraries
Provides:       %{name} = %{version}-%{release}
Provides:       %{name}%{major} = %{version}-%{release}

%description -n	%{libname}
The 'libffi' library provides a portable, high level programming interface to
various calling conventions. This allows a programmer to call any function
specified by a call interface description at run time.

FFI stands for Foreign Function Interface. A foreign function interface is the
popular name for the interface that allows code written in one language to call
code written in another language. The 'libffi' library really only provides the
lowest, machine dependent layer of a fully featured foreign function interface.
A layer must exist above 'libffi' that handles type conversions for values
passed between the two languages.

%package -n	%{develname}
Summary:	Development files for %{name}
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	libffi-devel = %{version}-%{release}
Provides:	ffi%{major}-devel = %{version}-%{release}

%description -n	%{develname}
This package contains libraries and header files for developing
applications that use %{name}.


%prep
%autosetup -p1


%build
# use generic x86_64 target to avoid compiling non-portable code
%ifarch x86_64
%define target_arch_flag --with-gcc-arch=x86_64
%else
%define target_arch_flag %{nil}
%endif

# https://gitlab.gnome.org/GNOME/gobject-introspection/-/merge_requests/283
%configure --disable-static --disable-exec-static-tramp %{target_arch_flag}
%make_build


%install
%make_install LIBDIR=%{_libdir}


%files -n %{libname}
%license LICENSE
%doc README.md
%{_libdir}/*.so.%{major}{,.*}

%files -n %{develname}
%{_libdir}/pkgconfig/*.pc
%{_libdir}/*.so
%{_mandir}/man3/*
%{_infodir}/libffi.info.*
%{_includedir}/ffi*.h


%changelog
* Tue May 13 2025 daviddavid <daviddavid> 3.4.8-1.mga10
+ Revision: 2183227
- new version: 3.4.8

* Mon Feb 17 2025 daviddavid <daviddavid> 3.4.7-1.mga10
+ Revision: 2149149
- new version: 3.4.7

* Fri Sep 20 2024 daviddavid <daviddavid> 3.4.6-1.mga10
+ Revision: 2099418
- new version: 3.4.6

* Fri Apr 05 2024 wally <wally> 3.4.4-2.mga10
+ Revision: 2054639
- basesystem rebuild for i686

* Sun Oct 30 2022 wally <wally> 3.4.4-1.mga9
+ Revision: 1900306
- new version 3.4.4

* Tue Oct 04 2022 neoclust <neoclust> 3.4.3-1.mga9
+ Revision: 1894821
- New version 3.4.3

* Tue Mar 15 2022 umeabot <umeabot> 3.4.2-5.mga9
+ Revision: 1793740
- Mageia 9 Mass Rebuild
+ wally <wally>
- shorten descriptions
- drop multiarch support

* Wed Dec 01 2021 tv <tv> 3.4.2-4.mga9
+ Revision: 1760391
- Fix segfaults due to invalid opcodes by forcing generic x86_64 target (Joseph Wang)

* Tue Nov 30 2021 tmb <tmb> 3.4.2-3.mga9
+ Revision: 1760122
- rebuild for arm

* Fri Aug 06 2021 tmb <tmb> 3.4.2-2.mga9
+ Revision: 1739820
- disble static trampolines for now

* Thu Aug 05 2021 luigiwalser <luigiwalser> 3.4.2-1.mga9
+ Revision: 1739626
- 3.4.2
- update source URL
- library major is now 8

* Thu Aug 20 2020 ovitters <ovitters> 3.3-2.mga8
+ Revision: 1616552
- remove install-info scriptlets, rely on filetrigger instead (mga#27107)

* Thu Jun 11 2020 joequant <joequant> 3.3-1.mga8
+ Revision: 1592251
- update to 3.3

* Thu Feb 13 2020 umeabot <umeabot> 3.2.1-8.mga8
+ Revision: 1514092
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 3.2.1-7.mga7
+ Revision: 1298841
- Mageia 7 Mass Rebuild

* Wed Jun 06 2018 pterjan <pterjan> 3.2.1-6.mga7
+ Revision: 1234940
- Add a RH patch for aarch64 and fix patch application
+ kekepower <kekepower>
- Use new make macros

* Thu Feb 11 2016 umeabot <umeabot> 3.2.1-5.mga6
+ Revision: 955457
- Mageia 6 Mass Rebuild

* Tue Sep 15 2015 blino <blino> 3.2.1-4.mga6
+ Revision: 879692
- headers need to be multiarch (they have an arch macro defined)

* Sat Sep 12 2015 tv <tv> 3.2.1-3.mga6
+ Revision: 878328
- actually upload patch
- patch 0: install includes in std dir

* Fri Aug 21 2015 tmb <tmb> 3.2.1-2.mga6
+ Revision: 867584
- rebuild for new gcc

* Mon Jul 20 2015 sander85 <sander85> 3.2.1-1.mga6
+ Revision: 855769
- New version: 3.2.1

* Wed Oct 15 2014 umeabot <umeabot> 3.1-4.mga5
+ Revision: 745917
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.1-3.mga5
+ Revision: 681456
- Mageia 5 Mass Rebuild

* Sun Aug 10 2014 akien <akien> 3.1-2.mga5
+ Revision: 661520
- Fix pkg-config file (upstream patch)

* Wed Jun 04 2014 sander85 <sander85> 3.1-1.mga5
+ Revision: 632883
- New version: 3.1

* Sat Oct 19 2013 umeabot <umeabot> 3.0.13-2.mga4
+ Revision: 523735
- Mageia 4 Mass Rebuild

* Fri May 24 2013 tv <tv> 3.0.13-1.mga4
+ Revision: 426596
- new release

* Thu May 09 2013 colin <colin> 3.0.11-3.mga3
+ Revision: 412789
- Rename -devel package to fit library policy (gcj no longer conflicts)

* Sat Jan 12 2013 umeabot <umeabot> 3.0.11-2.mga3
+ Revision: 357102
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Aug 06 2012 luigiwalser <luigiwalser> 3.0.11-1.mga3
+ Revision: 278977
- 3.0.11 (updates major to 6)

* Fri Aug 26 2011 tv <tv> 3.0.10-1.mga2
+ Revision: 135554
- new release

* Sun Mar 27 2011 dmorgan <dmorgan> 3.0.9-4.mga1
+ Revision: 77949
- Add an other provides to help to choose the one we want

* Sun Mar 27 2011 dmorgan <dmorgan> 3.0.9-3.mga1
+ Revision: 77909
- Fix provides
+ ennael <ennael>
- clean spec file

* Wed Jan 12 2011 dmorgan <dmorgan> 3.0.9-2.mga1
+ Revision: 7046
- imported package libffi


* Sun Nov 28 2010 Oden Eriksson <oeriksson@mandriva.com> 3.0.9-2mdv2011.0
+ Revision: 602541
- rebuild

* Fri Jan 01 2010 Götz Waschk <waschk@mandriva.org> 3.0.9-1mdv2010.1
+ Revision: 484651
- update to new version 3.0.9

* Wed Sep 02 2009 Christophe Fergeau <cfergeau@mandriva.com> 3.0.8-2mdv2010.0
+ Revision: 425540
- rebuild

* Wed Feb 18 2009 Götz Waschk <waschk@mandriva.org> 3.0.8-1mdv2009.1
+ Revision: 342439
- update to new version 3.0.8

* Mon Dec 01 2008 Götz Waschk <waschk@mandriva.org> 3.0.7-1mdv2009.1
+ Revision: 308725
- update to new version 3.0.7

* Fri Sep 05 2008 Götz Waschk <waschk@mandriva.org> 3.0.6-2mdv2009.0
+ Revision: 281039
- fix conflict with gcc's libffi package

* Tue Sep 02 2008 Götz Waschk <waschk@mandriva.org> 3.0.6-1mdv2009.0
+ Revision: 278859
- new version
- update source URL
- add conflict with other libffi-devel

* Mon Sep 01 2008 Götz Waschk <waschk@mandriva.org> 3.0.5-1mdv2009.0
+ Revision: 278177
- import libffi


* Tue Jul 08 2008 Anthony Green <green@redhat.com> 3.0.5-1
- Upgrade to 3.0.5

* Fri Feb 15 2008 Anthony Green <green@redhat.com> 3.0.1-1
- Upgrade to 3.0.1

* Fri Feb 15 2008 Anthony Green <green@redhat.com> 2.99.9-1
- Upgrade to 2.99.9
- Require pkgconfig for the devel package.
- Update summary.

* Fri Feb 15 2008 Anthony Green <green@redhat.com> 2.99.8-1
- Upgrade to 2.99.8

* Thu Feb 14 2008 Anthony Green <green@redhat.com> 2.99.7-1
- Upgrade to 2.99.7

* Thu Feb 14 2008 Anthony Green <green@redhat.com> 2.99.6-1
- Upgrade to 2.99.6

* Thu Feb 14 2008 Anthony Green <green@redhat.com> 2.99.4-1
- Upgrade to 2.99.4

* Thu Feb 14 2008 Anthony Green <green@redhat.com> 2.99.3-1
- Upgrade to 2.99.3

* Thu Feb 14 2008 Anthony Green <green@redhat.com> 2.99.2-1
- Created.
